@@ -56,29 +56,29 @@ class DBBase:
     async def get_connection_args(self) -> ConnectionArgs:
         raise NotImplementedError()
 
-    async def connect(self) -> "Connection":
+    async def connect(self, connection_args: ConnectionArgs) -> "Connection":
         """Override this method to customize how the connection is open. For instance you could
         use a connection pool's acquire method.
         """
-        conn_args = await self.get_connection_args()
-        return await connect(**conn_args)
+        return await connect(**connection_args)
 
-    async def disconnect(self):
+    async def disconnect(self, connection: Connection):
         """Override this method to customize how the connection is closed. For instance you could
         use a connection pool's release method.
         """
-        await self._conn.close()
+        await connection.close()
 
     async def open(self) -> "DBBase":
         """Opens the connection."""
         if not self._conn:
-            self._conn = await self.connect()
+            conn_args = await self.get_connection_args()
+            self._conn = await self.connect(conn_args)
         return self
 
     async def close(self) -> "DBBase":
         """Closes the connection."""
         if self._conn:
-            await self.disconnect()
+            await self.disconnect(self._conn)
             self._conn = None
         return self
 
